// Clarida, Gali, Gertler model

var da pie r rstar tau u x lagsignal; 	  

varexo eps_u eps_a eps_tau signal_a;   

parameters phi beta kappa phi_x phi_pie alpha rho lambda delta; // DECLARATION OF THE DEEP PARAMETERS.

// Parameter Values  
beta    = 1.03^(-1/4);
phi_x   = 0.5;
phi_pie = 1.5;
alpha   = 0.8;
rho     = 0.9;
lambda  = 0.5;
delta   = 0.2;
phi     = 1;
theta   = 0.75;
kappa   = ((1-theta)*(1-beta*theta)*(1+phi))/(theta);

// DECLARATION OF THE (LINEAR) DSGE MODEL: 
model(linear);

    beta*pie(+1) + kappa*x = pie;                                      // Calvo Pricing Equation
    r - pie(+1)-rstar   = x(+1) - x;                                   // Intertemporal Equation
    alpha*r(-1) + u + (1-alpha)*phi_pie*pie + (1-alpha)*phi_x*x = r;   // Monetary Policy Rule
//    rstar = rho*da + (1-lambda)/(1+phi)*tau + signal_a;                           // Definition of the Natural Rate
    rstar = -(1-rho)*da + (1-lambda)/(1+phi)*tau + signal_a;                           // Definition of the Natural Rate
    da = rho*da(-1) + eps_a + lagsignal(-1);
    lagsignal=signal_a;
    tau       = lambda*tau(-1) + eps_tau;
    u         = delta*u(-1) + eps_u;

end;


shocks;
var eps_a;
stderr 1;
var eps_tau;
stderr 1;
var eps_u;
stderr 1;
var signal_a;
stderr 1;
end;


stoch_simul(irf=20,nograph) da pie r rstar tau u x; 
tt=1:3;
pie_signal_a(tt)
hours=x_signal_a(tt)-tau_signal_a(tt)/(1+phi)
rate=r_signal_a(tt)
naturalrate=rstar_signal_a(tt)

//if rstar is defined by line 27, set ip = 1 (in this case, da denotes the growth rate of technology)
//if rstar is defined by line 28, set ip = 2 (in this case, da denotes the log level of technology)

ip=2;

figure('name','response to epsilon technology shock');
subplot(231);
if ip == 1;
    plot(cumsum(da_eps_a));
elseif ip ==2;
    plot(da_eps_a);
end;
title('level of technology');
axis tight;
subplot(232);
plot(pie_eps_a);
title('inflation');
axis tight;
subplot(233);
plot(r_eps_a);
title('nominal rate of interest');
axis tight;
tt=1:20;
j1=2:20;
j0=1:19;
subplot(234);
plot(tt,rstar_eps_a,j0,r_eps_a(j0)-pie_eps_a(j1),'*-');
legend('natural rate','real rate, equilibrium');
axis tight;
subplot(235);
plot(x_eps_a-tau_eps_a/(1+phi));
title('hours worked');
axis tight;
subplot(236);
if ip == 1;
    plot(x_eps_a+cumsum(da_eps_a));
elseif ip == 2;
    plot(x_eps_a+da_eps_a);
end;
title('output');
axis tight;

figure('name','response to signal about technology shock');
subplot(231);
if ip == 1;
    plot(cumsum(da_signal_a));
elseif ip ==2;
    plot(da_signal_a);
end;
title('level of technology');
axis tight;
subplot(232);
plot(pie_signal_a);
title('inflation');
axis tight;
subplot(233);
plot(r_signal_a);
title('nominal rate of interest');
axis tight;
tt=1:20;
j1=2:20;
j0=1:19;
subplot(234);
plot(tt,rstar_signal_a,j0,r_signal_a(j0)-pie_signal_a(j1),'*-');
legend('natural rate','real rate, equilibrium');
axis tight;
subplot(235);
plot(x_signal_a-tau_signal_a/(1+phi));
title('hours worked');
axis tight;
subplot(236);
if ip == 1;
    plot(x_signal_a+cumsum(da_signal_a));
elseif ip == 2;
    plot(x_signal_a+da_signal_a);
end;
title('output');
axis tight;
